==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/sr-latn.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'sr-latn', {
	acccessKey: 'Pristupni taster',
	advanced: 'Napredni tagovi',
	advisoryContentType: 'Advisory vrsta sadržaja',
	advisoryTitle: 'Advisory naslov',
	anchor: {
		toolbar: 'Unesi/izmeni sidro',
		menu: 'Osobine sidra',
		title: 'Osobine sidra',
		name: 'Naziv sidra',
		errorName: 'Unesite naziv sidra',
		remove: 'Ukloni sidro'
	},
	anchorId: 'Po Id-u elementa',
	anchorName: 'Po nazivu sidra',
	charset: 'Linked Resource Charset',
	cssClasses: 'Stylesheet klase',
	emailAddress: 'E-Mail adresa',
	emailBody: 'Sadržaj poruke',
	emailSubject: 'Naslov',
	id: 'Id',
	info: 'Link Info',
	langCode: 'Smer jezika',
	langDir: 'Smer jezika',
	langDirLTR: 'S leva na desno (LTR)',
	langDirRTL: 'S desna na levo (RTL)',
	menu: 'Izmeni link',
	name: 'Naziv',
	noAnchors: '(Nema dostupnih sidra)',
	noEmail: 'Otkucajte adresu elektronske pote',
	noUrl: 'Unesite URL linka',
	other: '<остало>',
	popupDependent: 'Zavisno (Netscape)',
	popupFeatures: 'Mogućnosti popup prozora',
	popupFullScreen: 'Prikaz preko celog ekrana (IE)',
	popupLeft: 'Od leve ivice ekrana (px)',
	popupLocationBar: 'Lokacija',
	popupMenuBar: 'Kontekstni meni',
	popupResizable: 'Promenljive veličine',
	popupScrollBars: 'Scroll bar',
	popupStatusBar: 'Statusna linija',
	popupToolbar: 'Toolbar',
	popupTop: 'Od vrha ekrana (px)',
	rel: 'Odnos',
	selectAnchor: 'Odaberi sidro',
	styles: 'Stil',
	tabIndex: 'Tab indeks',
	target: 'Meta',
	targetFrame: '<okvir>',
	targetFrameName: 'Naziv odredišnog frejma',
	targetPopup: '<popup prozor>',
	targetPopupName: 'Naziv popup prozora',
	title: 'Link',
	toAnchor: 'Sidro na ovoj stranici',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'Unesi/izmeni link',
	type: 'Vrsta linka',
	unlink: 'Ukloni link',
	upload: 'Pošalji'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/sr-latn.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'sr-latn', {
	acccessKey: 'Pristupni taster',
	advanced: 'Napredni tagovi',
	advisoryContentType: 'Advisory vrsta sadržaja',
	advisoryTitle: 'Advisory naslov',
	anchor: {
		toolbar: 'Unesi/izmeni sidro',
		menu: 'Osobine sidra',
		title: 'Osobine sidra',
		name: 'Naziv sidra',
		errorName: 'Unesite naziv sidra',
		remove: 'Ukloni sidro'
	},
	anchorId: 'Po Id-u elementa',
	anchorName: 'Po nazivu sidra',
	charset: 'Linked Resource Charset',
	cssClasses: 'Stylesheet klase',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'E-Mail adresa',
	emailBody: 'Sadržaj poruke',
	emailSubject: 'Naslov',
	id: 'Id',
	info: 'Link Info',
	langCode: 'Smer jezika',
	langDir: 'Smer jezika',
	langDirLTR: 'S leva na desno (LTR)',
	langDirRTL: 'S desna na levo (RTL)',
	menu: 'Izmeni link',
	name: 'Naziv',
	noAnchors: '(Nema dostupnih sidra)',
	noEmail: 'Otkucajte adresu elektronske pote',
	noUrl: 'Unesite URL linka',
	noTel: 'Please type the phone number', // MISSING
	other: '<остало>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Zavisno (Netscape)',
	popupFeatures: 'Mogućnosti popup prozora',
	popupFullScreen: 'Prikaz preko celog ekrana (IE)',
	popupLeft: 'Od leve ivice ekrana (px)',
	popupLocationBar: 'Lokacija',
	popupMenuBar: 'Kontekstni meni',
	popupResizable: 'Promenljive veličine',
	popupScrollBars: 'Scroll bar',
	popupStatusBar: 'Statusna linija',
	popupToolbar: 'Toolbar',
	popupTop: 'Od vrha ekrana (px)',
	rel: 'Odnos',
	selectAnchor: 'Odaberi sidro',
	styles: 'Stil',
	tabIndex: 'Tab indeks',
	target: 'Meta',
	targetFrame: '<okvir>',
	targetFrameName: 'Naziv odredišnog frejma',
	targetPopup: '<popup prozor>',
	targetPopupName: 'Naziv popup prozora',
	title: 'Link',
	toAnchor: 'Sidro na ovoj stranici',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Unesi/izmeni link',
	type: 'Vrsta linka',
	unlink: 'Ukloni link',
	upload: 'Pošalji'
} );
